@@ -17,6 +17,7 @@ describe 'glance::api' do
       :backlog                        => '<SERVICE DEFAULT>',
       :workers                        => '7',
       :show_image_direct_url          => '<SERVICE DEFAULT>',
+      :show_multiple_locations        => '<SERVICE DEFAULT>',
       :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
       :filesystem_store_file_perm     => '<SERVICE DEFAULT>',
       :location_strategy              => '<SERVICE DEFAULT>',
@@ -40,9 +41,9 @@ describe 'glance::api' do
       :user_storage_quota             => '<SERVICE DEFAULT>',
       :image_cache_stall_time         => '<SERVICE DEFAULT>',
       :image_cache_max_size           => '<SERVICE DEFAULT>',
-      :cache_prefetcher_interval      => '<SERVICE DEFAULT>',
       :disk_formats                   => '<SERVICE DEFAULT>',
-      :pipeline                       => 'keystone',
+      :paste_deploy_flavor            => 'keystone',
+      :paste_deploy_config_file       => '<SERVICE DEFAULT>',
       :task_time_to_live              => '<SERVICE DEFAULT>',
       :task_executor                  => '<SERVICE DEFAULT>',
       :task_work_dir                  => '<SERVICE DEFAULT>',
@@ -52,6 +53,7 @@ describe 'glance::api' do
       :sync_db                        => true,
       :limit_param_default            => '<SERVICE DEFAULT>',
       :api_limit_max                  => '<SERVICE DEFAULT>',
+      :public_endpoint                => '<SERVICE DEFAULT>',
     }
   end
 
@@ -88,11 +90,12 @@ describe 'glance::api' do
         :user_storage_quota             => 0,
         :image_cache_stall_time         => '10',
         :image_cache_max_size           => '10737418240',
-        :cache_prefetcher_interval      => '300',
-        :pipeline                       => 'keystone2',
+        :paste_deploy_flavor            => 'keystone+caching',
+        :paste_deploy_config_file       => 'glance-api-paste.ini',
         :sync_db                        => false,
         :limit_param_default            => '10',
         :api_limit_max                  => '10',
+        :public_endpoint                => 'https://cloud.acme.org/api/image',
       }
     ].each do |param_set|
 
@@ -125,7 +128,8 @@ describe 'glance::api' do
           'tag'        => 'glance-service',
         ) }
 
-        it { is_expected.to contain_glance_api_config("paste_deploy/flavor").with_value(param_hash[:pipeline]) }
+        it { is_expected.to contain_glance_api_config('paste_deploy/flavor').with_value(param_hash[:paste_deploy_flavor]) }
+        it { is_expected.to contain_glance_api_config('paste_deploy/config_file').with_value(param_hash[:paste_deploy_config_file]) }
 
         it 'is_expected.to lay down default api config' do
           [
@@ -140,7 +144,6 @@ describe 'glance::api' do
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
-            'cache_prefetcher_interval',
             'node_staging_uri',
             'worker_self_reference_url',
             'image_member_quota',
@@ -151,6 +154,7 @@ describe 'glance::api' do
             'user_storage_quota',
             'limit_param_default',
             'api_limit_max',
+            'public_endpoint',
           ].each do |config|
             is_expected.to contain_glance_api_config("DEFAULT/#{config}").with_value(param_hash[config.intern])
           end
@@ -228,7 +232,17 @@ describe 'glance::api' do
       it { is_expected.to_not contain_service('glance-api') }
     end
 
-    describe 'with overridden pipeline' do
+    describe 'with overridden flavor' do
+      let :params do
+        {
+          :paste_deploy_flavor => 'something',
+        }
+      end
+
+      it { is_expected.to contain_glance_api_config('paste_deploy/flavor').with_value('something') }
+    end
+
+    describe 'with flavor overridden by the deprecated pipeline parameter' do
       let :params do
         {
           :pipeline => 'something',
@@ -238,10 +252,53 @@ describe 'glance::api' do
       it { is_expected.to contain_glance_api_config('paste_deploy/flavor').with_value('something') }
     end
 
-    describe 'with blank pipeline' do
+    context 'when running glance-api in wsgi' do
       let :params do
         {
-          :pipeline => '',
+          :service_name => 'httpd'
+        }
+      end
+
+      let :pre_condition do
+        "include apache
+         class { 'glance': }
+         class { 'glance::api::authtoken':
+           password => 'foo',
+         }"
+      end
+
+      it 'configures glance-api service with Apache' do
+        is_expected.to contain_class('apache::params')
+        is_expected.to contain_service('glance-api').with(
+          :ensure => 'stopped',
+          :enable => false,
+          :tag    => ['glance-service'],
+        )
+      end
+    end
+
+    context 'when service_name is not valid' do
+      let :params do
+        {
+          :service_name => 'foobar'
+        }
+      end
+
+      let :pre_condition do
+        "include apache
+         class { 'glance': }
+         class { 'glance::api::authtoken':
+           password => 'foo',
+         }"
+      end
+
+      it_raises 'a Puppet::Error', /Invalid service_name/
+    end
+
+    describe 'with blank flavor' do
+      let :params do
+        {
+          :paste_deploy_flavor => '',
         }
       end
 
@@ -254,11 +311,11 @@ describe 'glance::api' do
       '+keystone',
       'keystone+cachemanagement+',
       '+'
-    ].each do |pipeline|
-      describe "with pipeline incorrect value #{pipeline}" do
+    ].each do |flavor|
+      describe "with flavor set by incorrect value #{flavor}" do
         let :params do
           {
-            :pipeline          => pipeline
+            :flavor => flavor
           }
         end
 
@@ -267,9 +324,25 @@ describe 'glance::api' do
       end
     end
 
+    describe 'with platform default oslo concurrency lock_path' do
+      it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
+        :lock_path => platform_params[:lock_path]
+      )}
+    end
+
+    describe 'with overridden oslo concurrency lock_path' do
+      let :params do
+        {:lock_path => '/glance/lock/path' }
+      end
+
+      it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
+        :lock_path => '/glance/lock/path',
+      )}
+    end
+
     describe 'setting enable_proxy_headers_parsing' do
       let :params do
-        default_params.merge({:enable_proxy_headers_parsing => true })
+        {:enable_proxy_headers_parsing => true }
       end
 
       it { is_expected.to contain_oslo__middleware('glance_api_config').with(
@@ -279,7 +352,7 @@ describe 'glance::api' do
 
     describe 'setting max_request_body_size' do
       let :params do
-        default_params.merge({:max_request_body_size => '102400' })
+        {:max_request_body_size => '102400' }
       end
 
       it { is_expected.to contain_oslo__middleware('glance_api_config').with(
@@ -289,10 +362,10 @@ describe 'glance::api' do
 
     describe 'with formats options with strings' do
       let :params do
-        default_params.merge({
+        {
           :container_formats => 'ami,ari',
           :disk_formats      => 'raw,iso',
-        })
+        }
       end
 
       context 'with disk_formats option' do
@@ -303,10 +376,10 @@ describe 'glance::api' do
 
     describe 'with formats options with arrays' do
       let :params do
-        default_params.merge({
+        {
           :container_formats => ['ami', 'ari'],
           :disk_formats      => ['raw', 'iso'],
-        })
+        }
       end
 
       context 'with disk_formats option' do
@@ -316,22 +389,18 @@ describe 'glance::api' do
     end
 
     describe 'with enabled_backends and stores by default' do
-      let :params do
-        default_params
-      end
-
       it { is_expected.to_not contain_glance_api_config('DEFAULT/enabled_backends').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
     end
 
     describe 'with enabled_backends' do
       let :params do
-        default_params.merge({
+        {
           :enabled_backends => ['file1:file','http1:http'],
           :default_backend  => 'file1',
           :stores           => ['file','http'],
           :default_store    => 'file',
-        })
+        }
       end
 
       it { is_expected.to contain_glance_api_config('DEFAULT/enabled_backends').with_value('file1:file,http1:http') }
@@ -342,10 +411,10 @@ describe 'glance::api' do
 
     describe 'with invalid backend type' do
       let :params do
-        default_params.merge({
+        {
           :enabled_backends => ['file1:file','bad1:mybad'],
           :default_backend  => 'file',
-        })
+        }
       end
 
       it_raises 'a Puppet::Error', / is not a valid backend type./
@@ -353,9 +422,9 @@ describe 'glance::api' do
 
     describe 'with enabled_backends but no default_backend' do
       let :params do
-        default_params.merge({
+        {
           :enabled_backends => ['file1:file','http1:http'],
-        })
+        }
       end
 
       it_raises 'a Puppet::Error', /A glance default_backend must be specified./
@@ -363,10 +432,10 @@ describe 'glance::api' do
 
     describe 'with duplicate backend identifiers' do
       let :params do
-        default_params.merge({
+        {
           :enabled_backends => ['file1:file','file1:http'],
           :default_backend  => 'file1',
-        })
+        }
       end
 
       it_raises 'a Puppet::Error', /All backend identifiers in enabled_backends must be unique./
@@ -374,10 +443,10 @@ describe 'glance::api' do
 
     describe 'with invalid default_backend' do
       let :params do
-        default_params.merge({
+        {
           :enabled_backends => ['file1:file','http1:http'],
           :default_backend  => 'file2',
-        })
+        }
       end
 
       it_raises 'a Puppet::Error', / is not a valid backend identifier./
@@ -385,11 +454,11 @@ describe 'glance::api' do
 
     describe 'with stores override' do
       let :params do
-        default_params.merge({
+        {
           :default_store => 'file',
           :stores        => ['file','http'],
           :multi_store   => true,
-        })
+        }
       end
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
@@ -398,10 +467,10 @@ describe 'glance::api' do
 
     describe 'with single store override and no default store' do
       let :params do
-        default_params.merge({
+        {
           :stores      => ['file'],
           :multi_store => true,
-        })
+        }
       end
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
@@ -410,10 +479,10 @@ describe 'glance::api' do
 
     describe 'with multiple stores override and no default store' do
       let :params do
-        default_params.merge({
+        {
           :stores      => ['file', 'http'],
           :multi_store => true,
-        })
+        }
       end
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
@@ -422,10 +491,10 @@ describe 'glance::api' do
 
     describe 'with default_store' do
       let :params do
-        default_params.merge({
+        {
           :default_store => 'file',
           :multi_store   => true,
-        })
+        }
       end
 
       it { is_expected.to contain_glance_api_config('glance_store/default_store').with_value('file') }
@@ -434,14 +503,14 @@ describe 'glance::api' do
 
     describe 'with task & taskflow configuration' do
       let :params do
-        default_params.merge({
+        {
           :task_time_to_live    => 72,
           :task_executor        => 'taskflow-next-gen',
           :task_work_dir        => '/tmp/large',
           :taskflow_engine_mode => 'serial',
           :taskflow_max_workers => 1,
           :conversion_format    => 'raw',
-        })
+        }
       end
 
       it 'is_expected.to lay down default task & taskflow_executor config' do
@@ -453,31 +522,16 @@ describe 'glance::api' do
         is_expected.to contain_glance_api_config('taskflow_executor/conversion_format').with_value('raw')
       end
     end
-
-    describe 'with barbican parameters' do
-      let :params do
-        default_params.merge!({
-          :keymgr_backend             => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
-          :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
-          :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
-        })
-      end
-      it 'should set keymgr parameters' do
-        is_expected.to contain_glance_api_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
-        is_expected.to contain_glance_api_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
-        is_expected.to contain_glance_api_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
-      end
-    end
   end
 
   shared_examples_for 'glance::api on Debian' do
-    let(:params) { default_params }
-
     # We only test this on Debian platforms, since on RedHat there isn't a
     # separate package for glance API.
     ['present', 'latest'].each do |package_ensure|
       context "with package_ensure '#{package_ensure}'" do
-        let(:params) { default_params.merge({ :package_ensure => package_ensure }) }
+        let(:params) do
+          { :package_ensure => package_ensure }
+        end
         it { is_expected.to contain_package('glance-api').with(
           :ensure => package_ensure,
           :tag    => ['openstack', 'glance-package']
@@ -494,6 +548,15 @@ describe 'glance::api' do
         facts.merge!(OSDefaults.get_facts())
       end
 
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :lock_path => '/var/lock/glance' }
+        when 'RedHat'
+          { :lock_path => '/var/lib/glance/tmp' }
+        end
+      end
+
       it_configures 'glance::api'
       if facts[:osfamily] == 'Debian'
         it_configures "glance::api on #{facts[:osfamily]}"
